pub struct MigrationInfo {
pub target: String,
pub writes_only: bool,
pub metrics: Arc<MirrorMetrics>,
pub config: MirrorConfig,
pub cutover: Arc<ArcSwap<Option<Arc<CutoverTarget>>>>,
pub cutover_target: CutoverTarget,
}Expand description
What the admin API needs to report migration status, without owning the mirror worker.
Fields
target: Stringwrites_only: boolmetrics: Arc<MirrorMetrics>config: MirrorConfigMirror config (source + target) for snapshot bootstrap.
cutover: Arc<ArcSwap<Option<Arc<CutoverTarget>>>>The proxy’s cutover switch and the target to promote to.
cutover_target: CutoverTargetTrait Implementations
Sourceimpl Clone for MigrationInfo
impl Clone for MigrationInfo
Sourcefn clone(&self) -> MigrationInfo
fn clone(&self) -> MigrationInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for MigrationInfo
impl RefUnwindSafe for MigrationInfo
impl Send for MigrationInfo
impl Sync for MigrationInfo
impl Unpin for MigrationInfo
impl UnsafeUnpin for MigrationInfo
impl UnwindSafe for MigrationInfo