pub struct L3SemanticCache { /* private fields */ }Expand description
L3 semantic cache (vector similarity)
This cache stores query embeddings and uses cosine similarity to find matches even when queries are not identical.
Implementations
Sourceimpl L3SemanticCache
impl L3SemanticCache
Sourcepub async fn get(
&self,
query: &str,
context: &CacheContext,
) -> Option<CachedResult>
pub async fn get( &self, query: &str, context: &CacheContext, ) -> Option<CachedResult>
Look up a query using semantic similarity
Sourcepub async fn put(
&self,
query: &str,
context: &CacheContext,
result: CachedResult,
)
pub async fn put( &self, query: &str, context: &CacheContext, result: CachedResult, )
Store a query and result in the semantic cache
Sourcepub fn stats(&self) -> L3CacheStats
pub fn stats(&self) -> L3CacheStats
Get cache statistics
Sourcepub async fn health_check(&self) -> bool
pub async fn health_check(&self) -> bool
Check if the embedding service is available