LagRoutingConfig

Struct LagRoutingConfig 

pub struct LagRoutingConfig {
Show 14 fields pub enabled: bool, pub poll_interval: Duration, pub lag_calculation: LagCalculation, pub default_max_lag: Duration, pub fresh_threshold: Duration, pub stale_threshold: Duration, pub fallback_to_primary: bool, pub fallback_threshold: Duration, pub read_your_writes: bool, pub ryw_retention: Duration, pub sync_mode_limits: HashMap<SyncMode, SyncModeLagConfig>, pub enable_smoothing: bool, pub smoothing_window: usize, pub min_samples: usize,
}
Main configuration for lag-aware routing

Fields

enabled: bool

Enable lag-aware routing

poll_interval: Duration

Interval between lag status polls

lag_calculation: LagCalculation

Method for calculating lag

default_max_lag: Duration

Default maximum acceptable lag for reads

fresh_threshold: Duration

Threshold for considering a node “fresh”

stale_threshold: Duration

Threshold for marking a node unhealthy due to lag

fallback_to_primary: bool

Whether to fall back to primary when all standbys are too laggy

fallback_threshold: Duration

Lag threshold that triggers primary fallback

read_your_writes: bool

Enable read-your-writes tracking

ryw_retention: Duration

How long to retain RYW LSN requirements

sync_mode_limits: HashMap<SyncMode, SyncModeLagConfig>

Per-sync-mode lag limits

enable_smoothing: bool

Enable lag trend smoothing to avoid oscillation

smoothing_window: usize

Number of samples for trend smoothing

min_samples: usize

Minimum samples before trusting lag data

Implementations

Source

impl LagRoutingConfig

pub fn new() -> Self

Create a new config with all defaults

pub fn with_poll_interval(self, interval: Duration) -> Self

Builder pattern: set poll interval

pub fn with_default_max_lag(self, lag: Duration) -> Self

Builder pattern: set default max lag

pub fn with_fallback_threshold(self, threshold: Duration) -> Self

Builder pattern: set fallback threshold

pub fn with_read_your_writes(self, enabled: bool) -> Self

Builder pattern: enable/disable read-your-writes

pub fn with_ryw_retention(self, retention: Duration) -> Self

Builder pattern: set RYW retention

pub fn with_lag_calculation(self, method: LagCalculation) -> Self

Builder pattern: set lag calculation method

pub fn with_smoothing(self, enabled: bool, window: usize) -> Self

Builder pattern: enable/disable smoothing

pub fn get_sync_mode_max_lag(&self, mode: SyncMode) -> Duration

Get the max lag allowed for a sync mode

pub fn get_sync_mode_weight(&self, mode: SyncMode) -> f64

Get the weight for a sync mode (for load balancing)