pub fn spawn(config: MirrorConfig) -> MirrorHandleExpand description
Spawn the mirror worker. Returns a handle for the data path to feed.
pub fn spawn(config: MirrorConfig) -> MirrorHandleSpawn the mirror worker. Returns a handle for the data path to feed.