SlidingWindow

Struct SlidingWindow 

pub struct SlidingWindow { /* private fields */ }
Sliding window rate limiter

Tracks events over a rolling time window, allowing precise rate limiting over time periods like “100 queries per minute”.

Implementations

Source

impl SlidingWindow

pub fn new(window_size: Duration, max_events: u32) -> Self

Create a new sliding window

Arguments
  • window_size - Duration of the sliding window
  • max_events - Maximum events allowed within the window
pub fn per_second(max_events: u32) -> Self

Create a sliding window for events per second

pub fn per_minute(max_events: u32) -> Self

Create a sliding window for events per minute

pub fn per_hour(max_events: u32) -> Self

Create a sliding window for events per hour

pub fn try_record(&self) -> Result<(), SlidingWindowExceeded>

Try to record an event

Returns Ok(()) if event was recorded, Err with wait time if limit exceeded.

pub fn try_record_n(&self, count: u32) -> Result<(), SlidingWindowExceeded>

Try to record multiple events

pub fn record_blocking( &self, timeout: Duration, ) -> Result<(), SlidingWindowExceeded>

Record an event, blocking until allowed (with timeout)

pub fn current_count(&self) -> u32

Get current event count in window

pub fn remaining_capacity(&self) -> u32

Get remaining capacity

pub fn window_size(&self) -> Duration

Get window size

pub fn max_events(&self) -> u32

Get max events

pub fn utilization(&self) -> f64

Get utilization ratio (0.0 - 1.0)

pub fn total_events(&self) -> u64

Get total events processed

pub fn rejected_events(&self) -> u64

Get total events rejected

pub fn rejection_rate(&self) -> f64

Get rejection rate (0.0 - 1.0)

pub fn reset(&self)

Reset the sliding window

pub fn current_rate(&self) -> f64

Get event rate (events per second)

pub fn time_until_available(&self) -> Duration

Estimate time until an event can be recorded

pub fn set_max_events(&mut self, max_events: u32)

Update max events (for dynamic limits)

pub fn set_window_size(&mut self, window_size: Duration)

Update window size (for dynamic limits)