TokenBucket

Struct TokenBucket 

pub struct TokenBucket { /* private fields */ }
Token bucket rate limiter

The token bucket allows for burst traffic up to the bucket capacity, while enforcing a sustained rate over time.

Implementations

Source

impl TokenBucket

pub fn new(capacity: u32, refill_rate: f64) -> Self

Create a new token bucket

Arguments
  • capacity - Maximum tokens (burst capacity)
  • refill_rate - Tokens added per second
pub fn from_qps(qps: u32, burst: u32) -> Self

Create a token bucket from QPS configuration

pub fn try_acquire(&self, tokens: u32) -> Result<(), TokenBucketExceeded>

Try to acquire tokens

Returns Ok(()) if tokens were acquired, Err with retry info if not.

pub fn acquire_blocking( &self, tokens: u32, timeout: Duration, ) -> Result<(), TokenBucketExceeded>

Acquire tokens, blocking until available (with timeout)

pub fn return_tokens(&self, tokens: u32)

Return tokens to the bucket (e.g., if operation was cancelled)

pub fn current_tokens(&self) -> u32

Get current token count

pub fn capacity(&self) -> u32

Get capacity

pub fn refill_rate(&self) -> f64

Get refill rate (tokens per second)

pub fn is_empty(&self) -> bool

Check if bucket is empty

pub fn is_full(&self) -> bool

Check if bucket is full

pub fn fill_ratio(&self) -> f64

Get fill percentage (0.0 - 1.0)

pub fn reset(&self)

Reset bucket to full capacity

pub fn set_capacity(&mut self, capacity: u32)

Update capacity (for dynamic limits)

pub fn set_refill_rate(&mut self, rate: f64)

Update refill rate (for dynamic limits)